import { IGridResourceStrings } from '../../core/i18n/grid-resources';
import { GridColumnDataType } from '../../data-operations/data-util';
import { IPivotDimension } from './pivot-grid.interface';
export interface IPivotDateDimensionOptions {
    /** Enables/Disables total value of all periods. */
    total?: boolean;
    /** Enables/Disables dimensions per year from provided periods. */
    years?: boolean;
    quarters?: boolean;
    /** Enables/Disables dimensions per month from provided periods. */
    months?: boolean;
    /** Enabled/Disables dimensions for the full date provided */
    fullDate?: boolean;
}
export declare class IgxPivotDateDimension implements IPivotDimension {
    /** Enables/Disables a particular dimension from pivot structure. */
    enabled: boolean;
    /**
     * Gets/Sets data type
     */
    dataType?: GridColumnDataType;
    /** Default options. */
    defaultOptions: {
        total: boolean;
        years: boolean;
        months: boolean;
        fullDate: boolean;
    };
    /**
     * Gets/Sets the resource strings.
     *
     * @remarks
     * By default it uses EN resources.
     */
    set resourceStrings(value: IGridResourceStrings);
    get resourceStrings(): IGridResourceStrings;
    /**
     * Gets/Sets the base dimension that is used by this class to determine the other dimensions and their values.
     * Having base dimension set is required in order for the Date Dimensions to show.
     */
    get baseDimension(): IPivotDimension;
    set baseDimension(value: IPivotDimension);
    /**
     * Gets/Sets the options for the predefined date dimensions whether to show quarter, years and etc.
     */
    get options(): IPivotDateDimensionOptions;
    set options(value: IPivotDateDimensionOptions);
    /**
     * @deprecated since version 15.1.0. Use the `baseDimension` property instead.
     *
     * Gets the base dimension that is used by this class to determine the other dimensions and their values.
     * Having base dimension set is required in order for the Date Dimensions to show.
     */
    get inBaseDimension(): IPivotDimension;
    /**
     * @deprecated since version 15.1.0. Use the `options` property instead.
     *
     * Gets the options for the predefined date dimensions whether to show quarter, years and etc.
     */
    get inOptions(): IPivotDateDimensionOptions;
    /** @hidden @internal */
    childLevel?: IPivotDimension;
    /** @hidden @internal */
    memberName: string;
    displayName: string;
    private _resourceStrings;
    private _baseDimension;
    private _options;
    private _monthIntl;
    /**
     * Creates additional pivot date dimensions based on a provided dimension describing date data:
     *
     * @param inDateDimension Base dimension that is used by this class to determine the other dimensions and their values.
     * @param inOptions Options for the predefined date dimensions whether to show quarter, years and etc.
     * @example
     * ```typescript
     * // Displays only years as parent dimension to the base dimension provided.
     * new IgxPivotDateDimension({ memberName: 'Date', enabled: true }, { total: false, months: false });
     * ```
     */
    constructor(inBaseDimension: IPivotDimension, inOptions?: IPivotDateDimensionOptions);
    protected initialize(inBaseDimension: any, inOptions: any): void;
    /** @hidden @internal */
    memberFunction: (_data: any) => string;
}
